@@ -13,7 +13,7 @@ sub pid       { $INST->pid }
 sub tid       { $INST->tid }
 sub stack     { $INST->stack }
 sub ipc       { $INST->ipc }
-sub formatter { $INST->format }
+sub formatter { $INST->formatter }
 sub init_done { $INST->finalized }
 sub load_done { $INST->loaded }
 
@@ -29,12 +29,15 @@ sub add_context_release_callback { shift; $INST->add_context_release_callback(@_
 sub add_post_load_callback       { shift; $INST->add_post_load_callback(@_) }
 sub add_exit_callback            { shift; $INST->add_exit_callback(@_) }
 
+sub add_formatter { shift; $INST->add_formatter(@_) }
+sub formatters    { @{$INST->formatters} }
+
 sub set_formatter {
     my $class = shift;
-    my ($format) = @_;
-    croak "No formatter specified" unless $format;
-    croak "Global Formatter already set" if $INST->format_set;
-    $INST->set_format($format);
+    my ($formater) = @_;
+    croak "No formatter specified" unless $formater;
+    croak "Global Formatter already set" if $INST->formatter_set;
+    $INST->set_format($formater);
 }
 
 sub no_wait {
@@ -156,22 +159,22 @@ Turn off IPC polling.
 This will return the global formatter class. This is not an instance. By
 default the formatter is set to L<Test2::Formatter::TAP>.
 
-You can override this default using the C<TS_FORMATTER> environment variable.
+You can override this default using the C<T2_FORMATTER> environment variable.
 
 Normally 'Test2::Formatter::' is prefixed to the value in the
 environment variable:
 
-    $ TS_FORMATTER='TAP' perl test.t     # Use the Test2::Formatter::TAP formatter
-    $ TS_FORMATTER='Foo' perl test.t     # Use the Test2::Formatter::Foo formatter
+    $ T2_FORMATTER='TAP' perl test.t     # Use the Test2::Formatter::TAP formatter
+    $ T2_FORMATTER='Foo' perl test.t     # Use the Test2::Formatter::Foo formatter
 
 If you want to specify a full module name you use the '+' prefix:
 
-    $ TS_FORMATTER='+Foo::Bar' perl test.t     # Use the Foo::Bar formatter
+    $ T2_FORMATTER='+Foo::Bar' perl test.t     # Use the Foo::Bar formatter
 
 =item Test2::Global->set_formatter($class)
 
 Set the global formatter class. This can only be set once. B<Note:> This will
-override anything specified in the 'TS_FORMATTER' environment variable.
+override anything specified in the 'T2_FORMATTER' environment variable.
 
 =item $bool = Test2::Global->no_wait
 
@@ -188,7 +191,7 @@ This can be used to add a callback that is called after all testing is done. Thi
 is too late to add additional results, the main use of this callback is to set the
 exit code.
 
-    Test2::Global->add_callback(
+    Test2::Global->add_exit_callback(
         sub {
             my ($context, $exit, \$new_exit) = @_;
             ...
